Use Case: Login To The Site
===========================

Actor
-----

Site Visitor

Overview
--------

Visitors to a site who have registered as members must login to the
site to use member-only services.

Procedure
---------

1. Visit the homepage of the site and click the "Log in" link on the menu
   (located at the left of the page in a default CMF site).

   The "Log in" link will take you to a form where you may enter your
   username and password for the site. You may also select the "remember my
   name" checkbox and the site will fill in your username on the form for you
   the next time you login.

2. Once you have entered your name and password, click the "Login" button to
   login to the site. You should then see a message letting you know that you
   have been successfully logged in. If you did not type your username or
   password correctly, you will see a page telling you that the login did not
   succeed.
